==> humhub-1.6.4.tar.gz: humhub-1.6.4/protected/humhub/modules/tour/messages/hr/base.php <==
<?php
return array (
  ' Remove panel' => 'Ukloni panel',
  '<strong>Account</strong> Menu' => '<strong>Račun</strong> - izbornik',
  '<strong>Getting</strong> Started' => '<strong>Sami</strong> Početak',
  '<strong>Guide:</strong> Administration (Modules)' => '<strong>Vodič:</strong> Administrativni (Moduli)',
  '<strong>Guide:</strong> Overview' => '<strong>Vodič:</strong> Pregled',
  '<strong>Guide:</strong> Spaces' => '<strong>Vodič:</strong> Prostori',
  '<strong>Guide:</strong> User profile' => '<strong>Vodič:</strong> Korisnički profil',
  '<strong>Notifications</strong>' => '<strong>Obavijesti</strong>',
  '<strong>Remove</strong> tour panel' => '<strong>Ukloni</strong> tour panel',
  '<strong>Space</strong> Menu' => '<strong>Prostor</strong> - izbornik',
  '<strong>Start</strong> space guide' => '<strong>Početak</strong> - vodič kroz prostor',
  'Cancel' => 'Poništi',
  'Don\'t lose track of things!<br /><br />This icon will keep you informed of activities and posts that concern you directly.' => 'Nemojte gubiti tragove! <br /> <br /> Ova ikona će vas informirati o aktivnostima i objavama koje se na vas izravno odnose.',
  'Drag a photo here or click to browse your files' => 'Ovdje povucite fotografiju ili kliknite da biste pregledavali svoje datoteke',
  'End guide' => 'Kraj vodiča',
  'Get to know your way around the site\'s most important features with the following guides:' => 'Upoznajte kretanje po najvažnijim značajkama web mjesta pomoću sljedećih vodiča:',
  'Hide my year of birth' => 'Sakrij godinu rođenja',
  'Howdy <strong>%firstname%</strong>, thank you for using %community%.' => '',
  'Next »' => 'Iduće',
  'Ok' => 'Ok',
  'Save and close' => 'Spremi i zatvori',
  'The account menu gives you access to your private settings and allows you to manage your public profile.' => 'Izbornik računa omogućuje vam pristup privatnim postavkama i omogućuje vam upravljanje vašim javnim profilom.',
  'This action will remove the tour panel from your dashboard. You can reactivate it at<br>Account settings <i class="fa fa-caret-right"></i> Settings.' => 'Ta radnja uklonit će turneju s ploče s instrumentima. Možete ju ponovno aktivirati na stranici <br> Postavke računa <i class = "fa fa-caret-right"> </ i> Postavke.',
  'This is the most important menu and will probably be the one you use most often!<br><br>Access all the spaces you have joined and create new spaces here.<br><br>The next guide will show you how:' => 'Ovo je najvažniji izbornik i vjerojatno će vam biti najčešće korišten! <br> <br> Pristupite svim prostorima kojima ste se pridružili i kreirajte nove prostore ovdje. <br> <br> Sljedeći vodič će vam pokazati kako:',
  'You are the first user here... Yehaaa! Be a shining example and complete your profile,<br>so that future users know who is the top dog here and to whom they can turn to if they have questions.' => 'Ti si prvi korisnik ovdje ... Yehaaa! Budi sjajan primjer i ispuni svoj profil, kako bi budući korisnici znali tko je ovdje iskusni korisnik i kome se mogu obratiti ako imaju pitanja.',
  'Your firstname' => 'Ime',
  'Your lastname' => 'Prezime',
  'Your mobile phone number' => 'Vaš broj mobitela',
  'Your phone number at work' => 'Vaš broj telefona na poslu',
  'Your skills, knowledge and experience (comma seperated)' => 'Vaše vještine, znanja i iskustvo (odvojeno zarezom)',
  'Your title or position' => 'Vaša titula ili pozicija',
  '« Prev' => 'Prethodno',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/tour/messages/hr/base.php <==
<?php
return array (
  ' Remove panel' => 'Ukloni panel',
  '<strong>Account</strong> Menu' => '<strong>Račun</strong> - izbornik',
  '<strong>Getting</strong> Started' => '<strong>Sami</strong> Početak',
  '<strong>Guide:</strong> Administration (Modules)' => '<strong>Vodič:</strong> Administrativni (Moduli)',
  '<strong>Guide:</strong> Overview' => '<strong>Vodič:</strong> Pregled',
  '<strong>Guide:</strong> Spaces' => '<strong>Vodič:</strong> Prostori',
  '<strong>Guide:</strong> User profile' => '<strong>Vodič:</strong> Korisnički profil',
  '<strong>Notifications</strong>' => '<strong>Obavijesti</strong>',
  '<strong>Remove</strong> tour panel' => '<strong>Ukloni</strong> tour panel',
  '<strong>Space</strong> Menu' => '<strong>Prostor</strong> - izbornik',
  '<strong>Start</strong> space guide' => '<strong>Početak</strong> - vodič kroz prostor',
  'Cancel' => 'Poništi',
  'Don\'t lose track of things!<br /><br />This icon will keep you informed of activities and posts that concern you directly.' => 'Nemojte gubiti tragove!<br><br>Ova ikona će vas informirati o aktivnostima i objavama koje se na vas izravno odnose.',
  'Drag a photo here or click to browse your files' => 'Ovdje povucite fotografiju ili kliknite da biste pregledavali svoje datoteke',
  'End guide' => 'Kraj vodiča',
  'Get to know your way around the site\'s most important features with the following guides:' => 'Upoznajte kretanje po najvažnijim značajkama web mjesta pomoću sljedećih vodiča:',
  'Hide my year of birth' => 'Sakrij godinu rođenja',
  'Howdy <strong>%firstname%</strong>, thank you for using %community%.' => 'Zdravo <strong>%firstname%</strong>, hvala vam što koristite %community%.',
  'Next »' => 'Iduće',
  'Ok' => 'Ok',
  'Save and close' => 'Spremi i zatvori',
  'The account menu gives you access to your private settings and allows you to manage your public profile.' => 'Izbornik računa omogućuje vam pristup privatnim postavkama i omogućuje vam upravljanje vašim javnim profilom.',
  'This action will remove the tour panel from your dashboard. You can reactivate it at<br>Account settings <i class="fa fa-caret-right"></i> Settings.' => 'Ta radnja uklonit će turneju s ploče s instrumentima. Možete ju ponovno aktivirati na stranici<br>Postavke računa <i class="fa fa-caret-right"></i> Postavke.',
  'This is the most important menu and will probably be the one you use most often!<br><br>Access all the spaces you have joined and create new spaces here.<br><br>The next guide will show you how:' => 'Ovo je najvažniji izbornik i vjerojatno će vam biti najčešće korišten!<br><br>Pristupite svim prostorima kojima ste se pridružili i kreirajte nove prostore ovdje.<br><br>Sljedeći vodič će vam pokazati kako:',
  'You are the first user here... Yehaaa! Be a shining example and complete your profile,<br>so that future users know who is the top dog here and to whom they can turn to if they have questions.' => 'Ti si prvi korisnik ovdje ... Yehaaa! Budi sjajan primjer i ispuni svoj profil, kako bi budući korisnici znali tko je ovdje iskusni korisnik i kome se mogu obratiti ako imaju pitanja.',
  'Your firstname' => 'Ime',
  'Your lastname' => 'Prezime',
  'Your mobile phone number' => 'Vaš broj mobitela',
  'Your phone number at work' => 'Vaš broj telefona na poslu',
  'Your skills, knowledge and experience (comma seperated)' => 'Vaše vještine, znanja i iskustvo (odvojeno zarezom)',
  'Your title or position' => 'Vaša titula ili pozicija',
  '« Prev' => 'Prethodno',
);
